@@ -1,8 +1,6 @@
 package Moose::Exception::InvalidValueForIs;
-BEGIN {
-  $Moose::Exception::InvalidValueForIs::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::InvalidValueForIs::VERSION = '2.1204';
+our $VERSION = '2.2207';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::InvalidAttributeOptions';
@@ -12,4 +10,5 @@ sub _build_message {
     "I do not understand this option (is => ".$self->params->{is}.") on attribute (".$self->attribute_name.")";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
