@@ -1,9 +1,6 @@
-
 package Class::MOP::Class;
-BEGIN {
-  $Class::MOP::Class::AUTHORITY = 'cpan:STEVAN';
-}
-$Class::MOP::Class::VERSION = '2.1204';
+our $VERSION = '2.2207';
+
 use strict;
 use warnings;
 
@@ -13,18 +10,17 @@ use Class::MOP::Method::Accessor;
 use Class::MOP::Method::Constructor;
 use Class::MOP::MiniTrait;
 
-use Carp         'confess';
+use Carp 'confess';
 use Module::Runtime 'use_package_optimistically';
-use Scalar::Util 'blessed', 'reftype', 'weaken';
-use Sub::Name    'subname';
+use Scalar::Util 'blessed';
+use Sub::Util 1.40 'set_subname';
 use Try::Tiny;
-use List::MoreUtils 'all';
+use List::Util 1.33 'all';
 
 use parent 'Class::MOP::Module',
          'Class::MOP::Mixin::HasAttributes',
-         'Class::MOP::Mixin::HasMethods';
-
-use Moose::Util 'throw_exception';
+         'Class::MOP::Mixin::HasMethods',
+         'Class::MOP::Mixin::HasOverloads';
 
 # Creation
 
@@ -41,7 +37,7 @@ sub initialize {
     }
 
     ($package_name && !ref($package_name))
-        || throw_exception( InitializeTakesUnBlessedPackageName => package_name => $package_name );
+        || ($class||__PACKAGE__)->_throw_exception( InitializeTakesUnBlessedPackageName => package_name => $package_name );
     return Class::MOP::get_metaclass_by_name($package_name)
         || $class->_construct_class_instance(package => $package_name, @_);
 }
@@ -76,7 +72,7 @@ sub _construct_class_instance {
     my $options      = @_ == 1 ? $_[0] : {@_};
     my $package_name = $options->{package};
     (defined $package_name && $package_name)
-        || throw_exception("ConstructClassInstanceTakesPackageName");
+        || $class->_throw_exception("ConstructClassInstanceTakesPackageName");
     # NOTE:
     # return the metaclass if we have it cached,
     # and it is still defined (it has not been
@@ -236,7 +232,8 @@ sub _check_class_metaclass_compatibility {
 
         my $super_meta_type = $super_meta->_real_ref_name;
 
-        throw_exception( IncompatibleMetaclassOfSuperclass => class                => $self,
+        $self->_throw_exception( IncompatibleMetaclassOfSuperclass => class_name           => $self->name,
+                                                              class_meta_type      => ref( $self ),
                                                               superclass_name      => $superclass_name,
                                                               superclass_meta_type => $super_meta_type
                        );
@@ -262,7 +259,7 @@ sub _check_single_metaclass_compatibility {
     if (!$self->_single_metaclass_is_compatible($metaclass_type, $superclass_name)) {
         my $super_meta = Class::MOP::get_metaclass_by_name($superclass_name);
 
-        throw_exception( MetaclassTypeIncompatible => class           => $self,
+        $self->_throw_exception( MetaclassTypeIncompatible => class_name      => $self->name,
                                                       superclass_name => $superclass_name,
                                                       metaclass_type  => $metaclass_type
                        );
@@ -365,7 +362,7 @@ sub _fix_class_metaclass_incompatibility {
 
     if ($self->_class_metaclass_can_be_made_compatible($super_meta)) {
         ($self->is_pristine)
-            || throw_exception( CannotFixMetaclassCompatibility => class      => $self,
+            || $self->_throw_exception( CannotFixMetaclassCompatibility => class_name => $self->name,
                                                                    superclass => $super_meta
                               );
 
@@ -381,7 +378,7 @@ sub _fix_single_metaclass_incompatibility {
 
     if ($self->_single_metaclass_can_be_made_compatible($super_meta, $metaclass_type)) {
         ($self->is_pristine)
-            || throw_exception( CannotFixMetaclassCompatibility => class          => $self,
+            || $self->_throw_exception( CannotFixMetaclassCompatibility => class_name     => $self->name,
                                                                    superclass     => $super_meta,
                                                                    metaclass_type => $metaclass_type
                               );
@@ -419,19 +416,19 @@ sub create {
     my %options = @args;
 
     (ref $options{superclasses} eq 'ARRAY')
-        || throw_exception( CreateMOPClassTakesArrayRefOfSuperclasses => class  => $class,
+        || __PACKAGE__->_throw_exception( CreateMOPClassTakesArrayRefOfSuperclasses => class  => $class,
                                                                          params => \%options
                           )
             if exists $options{superclasses};
 
     (ref $options{attributes} eq 'ARRAY')
-        || throw_exception( CreateMOPClassTakesArrayRefOfAttributes => class  => $class,
+        || __PACKAGE__->_throw_exception( CreateMOPClassTakesArrayRefOfAttributes => class  => $class,
                                                                        params => \%options
                           )
             if exists $options{attributes};
 
     (ref $options{methods} eq 'HASH')
-        || throw_exception( CreateMOPClassTakesHashRefOfMethods => class  => $class,
+        || __PACKAGE__->_throw_exception( CreateMOPClassTakesHashRefOfMethods => class  => $class,
                                                                    params => \%options
                           )
             if exists $options{methods};
@@ -510,16 +507,16 @@ sub _construct_instance {
     my $instance;
     if (my $instance_class = blessed($params->{__INSTANCE__})) {
         ($instance_class eq $class->name)
-            || throw_exception( InstanceBlessedIntoWrongClass => class    => $class,
-                                                                 params   => $params,
-                                                                 instance => $params->{__INSTANCE__}
+            || $class->_throw_exception( InstanceBlessedIntoWrongClass => class_name => $class->name,
+                                                                 params     => $params,
+                                                                 instance   => $params->{__INSTANCE__}
                               );
         $instance = $params->{__INSTANCE__};
     }
     elsif (exists $params->{__INSTANCE__}) {
-        throw_exception( InstanceMustBeABlessedReference => class    => $class,
-                                                            params   => $params,
-                                                            instance => $params->{__INSTANCE__}
+        $class->_throw_exception( InstanceMustBeABlessedReference => class_name => $class->name,
+                                                            params     => $params,
+                                                            instance   => $params->{__INSTANCE__}
                        );
     }
     else {
@@ -767,8 +764,8 @@ sub clone_object {
     my $class    = shift;
     my $instance = shift;
     (blessed($instance) && $instance->isa($class->name))
-        || throw_exception( CloneObjectExpectsAnInstanceOfMetaclass => class    => $class,
-                                                                       instance => $instance
+        || $class->_throw_exception( CloneObjectExpectsAnInstanceOfMetaclass => class_name => $class->name,
+                                                                       instance   => $instance,
                           );
     # NOTE:
     # we need to protect the integrity of the
@@ -781,9 +778,9 @@ sub clone_object {
 sub _clone_instance {
     my ($class, $instance, %params) = @_;
     (blessed($instance))
-        || throw_exception( OnlyInstancesCanBeCloned => class    => $class,
-                                                        instance => $instance,
-                                                        params   => \%params
+        || $class->_throw_exception( OnlyInstancesCanBeCloned => class_name => $class->name,
+                                                        instance   => $instance,
+                                                        params     => \%params
                           );
     my $meta_instance = $class->get_meta_instance();
     my $clone = $meta_instance->clone_instance($instance);
@@ -828,9 +825,10 @@ sub rebless_instance {
 
     my $old_class = $old_metaclass ? $old_metaclass->name : blessed($instance);
     $self->name->isa($old_class)
-        || throw_exception( CanReblessOnlyIntoASubclass => class    => $self,
-                                                           instance => $instance,
-                                                           params   => \%params
+        || $self->_throw_exception( CanReblessOnlyIntoASubclass => class_name     => $self->name,
+                                                           instance       => $instance,
+                                                           instance_class => blessed( $instance ),
+                                                           params         => \%params,
                           );
 
     $self->_force_rebless_instance($_[1], %params);
@@ -844,8 +842,9 @@ sub rebless_instance_back {
     my $old_class
         = $old_metaclass ? $old_metaclass->name : blessed($instance);
     $old_class->isa( $self->name )
-        || throw_exception( CanReblessOnlyIntoASuperclass => class    => $self,
-                                                             instance => $instance,
+        || $self->_throw_exception( CanReblessOnlyIntoASuperclass => class_name     => $self->name,
+                                                             instance       => $instance,
+                                                             instance_class => blessed( $instance ),
                           );
 
     $self->_force_rebless_instance($_[1]);
@@ -1060,7 +1059,7 @@ sub _method_lookup_order {
             $method = $self->find_next_method_by_name($method_name);
             # die if it does not exist
             (defined $method)
-                || throw_exception( MethodNameNotFoundInInheritanceHierarchy => class       => $self,
+                || $self->_throw_exception( MethodNameNotFoundInInheritanceHierarchy => class_name  => $self->name,
                                                                                 method_name => $method_name
                                   );
             # and now make sure to wrap it
@@ -1085,30 +1084,30 @@ sub _method_lookup_order {
     sub add_before_method_modifier {
         my ($self, $method_name, $method_modifier) = @_;
         (defined $method_name && length $method_name)
-            || throw_exception( MethodModifierNeedsMethodName => class => $self );
+            || $self->_throw_exception( MethodModifierNeedsMethodName => class_name => $self->name );
         my $method = $fetch_and_prepare_method->($self, $method_name);
         $method->add_before_modifier(
-            subname(':before' => $method_modifier)
+            set_subname(':before' => $method_modifier)
         );
     }
 
     sub add_after_method_modifier {
         my ($self, $method_name, $method_modifier) = @_;
         (defined $method_name && length $method_name)
-            || throw_exception( MethodModifierNeedsMethodName => class => $self );
+            || $self->_throw_exception( MethodModifierNeedsMethodName => class_name => $self->name );
         my $method = $fetch_and_prepare_method->($self, $method_name);
         $method->add_after_modifier(
-            subname(':after' => $method_modifier)
+            set_subname(':after' => $method_modifier)
         );
     }
 
     sub add_around_method_modifier {
         my ($self, $method_name, $method_modifier) = @_;
         (defined $method_name && length $method_name)
-            || throw_exception( MethodModifierNeedsMethodName => class => $self );
+            || $self->_throw_exception( MethodModifierNeedsMethodName => class_name => $self->name );
         my $method = $fetch_and_prepare_method->($self, $method_name);
         $method->add_around_modifier(
-            subname(':around' => $method_modifier)
+            set_subname(':around' => $method_modifier)
         );
     }
 
@@ -1129,7 +1128,7 @@ sub _method_lookup_order {
 sub find_method_by_name {
     my ($self, $method_name) = @_;
     (defined $method_name && length $method_name)
-        || throw_exception( MethodNameNotGiven => class => $self );
+        || $self->_throw_exception( MethodNameNotGiven => class_name => $self->name );
     foreach my $class ($self->_method_lookup_order) {
         my $method = Class::MOP::Class->initialize($class)->get_method($method_name);
         return $method if defined $method;
@@ -1158,7 +1157,7 @@ sub get_all_method_names {
 sub find_all_methods_by_name {
     my ($self, $method_name) = @_;
     (defined $method_name && length $method_name)
-        || throw_exception( MethodNameNotGiven => class => $self );
+        || $self->_throw_exception( MethodNameNotGiven => class_name => $self->name );
     my @methods;
     foreach my $class ($self->_method_lookup_order) {
         # fetch the meta-class ...
@@ -1175,7 +1174,7 @@ sub find_all_methods_by_name {
 sub find_next_method_by_name {
     my ($self, $method_name) = @_;
     (defined $method_name && length $method_name)
-        || throw_exception( MethodNameNotGiven => class => $self );
+        || $self->_throw_exception( MethodNameNotGiven => class_name => $self->name );
     my @cpl = ($self->_method_lookup_order);
     shift @cpl; # discard ourselves
     foreach my $class (@cpl) {
@@ -1336,8 +1335,8 @@ sub _immutable_metaclass {
     }
 
     my $trait = $args{immutable_trait} = $self->immutable_trait
-        || throw_exception( NoImmutableTraitSpecifiedForClass => class  => $self,
-                                                                 params => \%args
+        || $self->_throw_exception( NoImmutableTraitSpecifiedForClass => class_name => $self->name,
+                                                                 params     => \%args
                           );
 
     my $meta      = $self->meta;
@@ -1474,8 +1473,8 @@ sub _inline_destructor {
     my ( $self, %args ) = @_;
 
     ( exists $args{destructor_class} && defined $args{destructor_class} )
-        || throw_exception( NoDestructorClassSpecified => class  => $self,
-                                                          params => \%args
+        || $self->_throw_exception( NoDestructorClassSpecified => class_name => $self->name,
+                                                          params     => \%args,
                           );
 
     if ( $self->has_method('DESTROY') && ! $args{replace_destructor} ) {
@@ -1528,7 +1527,7 @@ Class::MOP::Class - Class Meta Object
 
 =head1 VERSION
 
-version 2.1204
+version 2.2207
 
 =head1 SYNOPSIS
 
@@ -1604,6 +1603,7 @@ An optional version number for the newly created package.
 =item * authority
 
 An optional authority for the newly created package.
+See L<Class::MOP::Module/authority> for more details.
 
 =item * superclasses
 
@@ -1818,8 +1818,8 @@ Determining what is truly a method in a Perl 5 class requires some
 heuristics (aka guessing).
 
 Methods defined outside the package with a fully qualified name (C<sub
-Package::name { ... }>) will be included. Similarly, methods named
-with a fully qualified name using L<Sub::Name> are also included.
+Package::name { ... }>) will be included. Similarly, methods named with a
+fully qualified name using L<Sub::Util> are also included.
 
 However, we attempt to ignore imported functions.
 
@@ -2003,12 +2003,12 @@ These methods provide an API to the core L<overload> functionality.
 =item B<< $metaclass->is_overloaded >>
 
 Returns true if overloading is enabled for this class. Corresponds to
-L<overload::Overloaded|overload/Public Functions>.
+L<Devel::OverloadInfo/is_overloaded>.
 
 =item B<< $metaclass->get_overloaded_operator($op) >>
 
-Returns the L<Class::MOP::Method::Overload> object corresponding to the
-operator named C<$op>, if one exists for this class.
+Returns the L<Class::MOP::Overload> object corresponding to the operator named
+C<$op>, if one exists for this class.
 
 =item B<< $metaclass->has_overloaded_operator($op) >>
 
@@ -2021,19 +2021,27 @@ L<overload/Overloadable Operations> for the list of valid operator names).
 
 =item B<< $metaclass->get_all_overloaded_operators >>
 
-Returns a list of L<Class::MOP::Method::Overload> objects corresponding to the
+Returns a list of L<Class::MOP::Overload> objects corresponding to the
 operators that have been overloaded.
 
 =item B<< $metaclass->add_overloaded_operator($op, $impl) >>
 
-Overloads the operator C<$op> for this class, with the implementation C<$impl>.
-C<$impl> can be either a coderef or a method name. Corresponds to
+Overloads the operator C<$op> for this class. The C<$impl> can be a coderef, a
+method name, or a L<Class::MOP::Overload> object. Corresponds to
 C<< use overload $op => $impl; >>
 
 =item B<< $metaclass->remove_overloaded_operator($op) >>
 
 Remove overloading for operator C<$op>. Corresponds to C<< no overload $op; >>
 
+=item B<< $metaclass->get_overload_fallback_value >>
+
+Returns the overload C<fallback> setting for the package.
+
+=item B<< $metaclass->set_overload_fallback_value($fallback) >>
+
+Sets the overload C<fallback> setting for the package.
+
 =back
 
 =head2 Class Immutability
@@ -2254,7 +2262,7 @@ metaclass.
 
 =item *
 
-Stevan Little <stevan.little@iinteractive.com>
+Stevan Little <stevan@cpan.org>
 
 =item *
 
@@ -2262,11 +2270,11 @@ Dave Rolsky <autarch@urth.org>
 
 =item *
 
-Jesse Luehrs <doy@tozt.net>
+Jesse Luehrs <doy@cpan.org>
 
 =item *
 
-Shawn M Moore <code@sartak.org>
+Shawn M Moore <sartak@cpan.org>
 
 =item *
 
@@ -2282,7 +2290,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =item *
 
-Hans Dieter Pearcey <hdp@weftsoar.net>
+Hans Dieter Pearcey <hdp@cpan.org>
 
 =item *
 
@@ -2290,13 +2298,13 @@ Chris Prather <chris@prather.org>
 
 =item *
 
-Matt S Trout <mst@shadowcat.co.uk>
+Matt S Trout <mstrout@cpan.org>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2006 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
