@@ -1,8 +1,6 @@
 package Moose::Exception::NoDestructorClassSpecified;
-BEGIN {
-  $Moose::Exception::NoDestructorClassSpecified::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::NoDestructorClassSpecified::VERSION = '2.1204';
+our $VERSION = '2.2207';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::Class', 'Moose::Exception::Role::ParamsHash';
@@ -11,4 +9,5 @@ sub _build_message {
     "The 'inline_destructor' option is present, but no destructor class was specified";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
