@@ -1,8 +1,6 @@
 package Moose::Exception::ReferencesAreNotAllowedAsDefault;
-BEGIN {
-  $Moose::Exception::ReferencesAreNotAllowedAsDefault::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::ReferencesAreNotAllowedAsDefault::VERSION = '2.1204';
+our $VERSION = '2.2207';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::ParamsHash';
@@ -25,4 +23,5 @@ sub _build_message {
         $self->attribute_name."' in a CODE reference (ex: sub { [] } and not [])";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
